<?php
namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Util\Utilities;
use Teknisa\Model\Teknisa\Repositories;

class NotificationParameters
{
    
     /**
     * @var EntityManager
     */
    protected $entityManager;
    /** @var TeknisaEnvironment **/
    
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }
    
    public function findNotificationParametersProdOrg($conditions)
    {
        $notificationServiceRepositoryProdOrg = InstanceProvider::getRepository()->getNotificationParametersProdOrg();
        $environment = InstanceProvider::getEnvironment();
        $filters = InstanceProvider::getUtilities()->createQueryFiltered($conditions);
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServiceRepositoryProdOrg->findNotificationServices($currentOrganizationId,$filters);
    }
    
    public function findServicesConfigurationProdOrgs($conditions)
    {
        $notificationServicesAppProdOrgRepository = InstanceProvider::getRepository()->getNotificationParametersAppProdOrg();
        $environment = InstanceProvider::getEnvironment();
        $nrserviconotif_id = Utilities::getValueInFilterDataSourceByName($conditions,"NRSERVICONOTIF_ID");
        $nrproduto_org_id = Utilities::getValueInFilterDataSourceByName($conditions,"NRPRODUTO_ORG_ID");
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServicesAppProdOrgRepository->findServicesConfigurationProdOrgs($currentOrganizationId,$nrserviconotif_id,$nrproduto_org_id);
    }
    
    public function saveServicesConfigurationProdOrgs($rows)
    {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $notificationServicesAppProdOrgRepository = InstanceProvider::getRepository()->getNotificationParametersAppProdOrg();
            $notificationServicesProdOrgRepository = InstanceProvider::getRepository()->getNotificationParametersProdOrg();
            $notificationServicesAppProdOrgFactory =  InstanceProvider::getFactory()->getNotificationParametersAppProdOrg();
            $notificationServicesProdOrgFactory = InstanceProvider::getFactory()->getNotificationParametersProdOrg();
            $environment = InstanceProvider::getEnvironment();
            $currentOrganizationId = $environment->getCurrentOrganizationId();
            $currentUserId = $environment->getCurrentUserId();
            $dateNow = new \DateTime;
            $notificationServicesProdOrgEntity = null;
            $notificationServicesAppProdOrgEntity = null;
            
            foreach ($rows as $row) {
                $id = empty($row['APPARAMPRODORG_ID']) ? NULL : $row['APPARAMPRODORG_ID'];
                if ($id) {
                    $notificationServicesAppProdOrgEntity = $notificationServicesAppProdOrgRepository->find($id);
                }else{
                    $notificationServicesAppProdOrgEntity = null;
                }
                $notificationServicesProdOrgEntity = $notificationServicesProdOrgFactory->save($notificationServicesProdOrgEntity, $row['IDATIVO'], $currentOrganizationId, $currentUserId, $dateNow, $row['NRSERVICONOTIF_ID'], $row['NRPRODUTO_ORG_ID']);
                $notificationServicesAppProdOrgEntity = $notificationServicesAppProdOrgFactory->save($notificationServicesAppProdOrgEntity, $row['IDATIVO'], $currentOrganizationId, $currentUserId, $dateNow, $row['ID'], $row['NRPRODUTO_ORG_ID'], $row['DSVALORAPPPARAM']);
                $this->entityManager->persist($notificationServicesProdOrgEntity);
                $this->entityManager->flush();
                $this->entityManager->persist($notificationServicesAppProdOrgEntity);
                $this->entityManager->flush();
            }
            $connection->commit();
            
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
    public function findServicesConfigurationProd($conditions)
    {
        $notificationServicesAppProdRepository = InstanceProvider::getRepository()->getNotificationParametersAppProd();
        $environment = InstanceProvider::getEnvironment();
        $nrserviconotif_id = Utilities::getValueInFilterDataSourceByName($conditions,"NRSERVICONOTIF_ID");
        $nrproduto_id = Utilities::getValueInFilterDataSourceByName($conditions,"NRPRODUTO_ID");
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServicesAppProdRepository->findServicesConfigurationProd($currentOrganizationId,$nrserviconotif_id,$nrproduto_id);
    }
    
    public function saveServicesConfigurationProd($rows)
    {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $notificationServicesAppProdRepository = InstanceProvider::getRepository()->getNotificationParametersAppProd();
            $notificationServicesProdRepository = InstanceProvider::getRepository()->getNotificationParametersProd();
            $notificationServicesAppProdFactory =  InstanceProvider::getFactory()->getNotificationParametersAppProd();
            $notificationServicesProdFactory = InstanceProvider::getFactory()->getNotificationParametersProd();
            $environment = InstanceProvider::getEnvironment();
            $currentOrganizationId = $environment->getCurrentOrganizationId();
            $currentUserId = $environment->getCurrentUserId();
            $dateNow = new \DateTime;
            $notificationServicesProdEntity = null;
            $notificationServicesAppProdEntity = null;
            
            foreach ($rows as $row) {
                $id = empty($row['APPARAMPROD_ID']) ? NULL : $row['APPARAMPROD_ID'];
                 if ($id) {
                    $notificationServicesAppProdEntity = $notificationServicesAppProdRepository->find($id);
                }else{
                    $notificationServicesAppProdEntity = null;
                }
                $notificationServicesProdEntity = $notificationServicesProdFactory->save($notificationServicesProdEntity, $row['IDATIVO'], $currentOrganizationId, $currentUserId, $dateNow, $row['NRSERVICONOTIF_ID'], $row['NRPRODUTO_ID']);
                $notificationServicesAppProdEntity = $notificationServicesAppProdFactory->save($notificationServicesAppProdEntity, $row['IDATIVO'], $currentOrganizationId, $currentUserId, $dateNow, $row['ID'], $row['NRPRODUTO_ID'], $row['DSVALORAPPPARAM']);
                $this->entityManager->persist($notificationServicesProdEntity);
                $this->entityManager->flush();
                $this->entityManager->persist($notificationServicesAppProdEntity);
                $this->entityManager->flush();
            }
            $connection->commit();
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
}